==> mesa-11.2.2.tar.xz: mesa-11.2.2/src/gallium/auxiliary/util/u_suballoc.h <==
/**************************************************************************
 *
 * Copyright 2009 VMware, Inc.
 * Copyright 2012 Marek Olšák <maraeo@gmail.com>
 * All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sub license, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice (including the
 * next paragraph) shall be included in all copies or substantial portions
 * of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS AND/OR ITS SUPPLIERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 **************************************************************************/

/* A simple allocator that suballocates memory from a large buffer. */

#ifndef U_SUBALLOC
#define U_SUBALLOC

struct u_suballocator;

struct u_suballocator *
u_suballocator_create(struct pipe_context *pipe, unsigned size,
                      unsigned alignment, unsigned bind, unsigned usage,
		      boolean zero_buffer_memory);

void
u_suballocator_destroy(struct u_suballocator *allocator);

void
u_suballocator_alloc(struct u_suballocator *allocator, unsigned size,
                     unsigned *out_offset, struct pipe_resource **outbuf);

#endif

==> mesa-12.0.0-rc4.tar.xz: mesa-12.0.0-rc4/src/gallium/auxiliary/util/u_suballoc.h <==
/**************************************************************************
 *
 * Copyright 2009 VMware, Inc.
 * Copyright 2012 Marek Olšák <maraeo@gmail.com>
 * All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sub license, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice (including the
 * next paragraph) shall be included in all copies or substantial portions
 * of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS AND/OR ITS SUPPLIERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 **************************************************************************/

/* A simple allocator that suballocates memory from a large buffer. */

#ifndef U_SUBALLOC
#define U_SUBALLOC

struct u_suballocator;

struct u_suballocator *
u_suballocator_create(struct pipe_context *pipe, unsigned size,
                      unsigned alignment, unsigned bind,
                      enum pipe_resource_usage usage,
		      boolean zero_buffer_memory);

void
u_suballocator_destroy(struct u_suballocator *allocator);

void
u_suballocator_alloc(struct u_suballocator *allocator, unsigned size,
                     unsigned *out_offset, struct pipe_resource **outbuf);

#endif
